@@ -1,19 +1,28 @@
 from enum import Enum, auto
+from typing import List, Any
 
 
-class Options(Enum):
+class AutoNameEnum(str, Enum):
+    def _generate_next_value_(  # type: ignore
+        name: str, start: int, count: int, last_values: List[str]
+    ) -> str:
+        return name.lower()
+
+
+class Options(AutoNameEnum):
     BULK_SIZE = auto()
     BULK_FLUSH_INTERVAL = auto()
     MAX_CONCURRENCY = auto()
+    CONNECTION_FAIL_CALLBACK = auto()
 
 
-class Actions(Enum):
+class Actions(AutoNameEnum):
     ACK = auto()
     REJECT = auto()
     REQUEUE = auto()
 
 
-class Events(Enum):
+class Events(AutoNameEnum):
     ON_SUCCESS = auto()
     ON_EXCEPTION = auto()
 
@@ -26,7 +35,7 @@ class DefaultValues:
     RUN_EVERY_MAX_CONCURRENCY = 1
 
 
-class RouteTypes(Enum):
+class RouteTypes(AutoNameEnum):
     AMQP_RABBITMQ = auto()
     SSE = auto()
     HTTP = auto()
