@@ -1,17 +1,23 @@
 import abc
+import asyncio
 from collections import UserList
 
 
 class Freezable(metaclass=abc.ABCMeta):
+    def __init__(self):
+        self._frozen = False
+
+    @property
     def frozen(self) -> bool:
-        raise NotImplementedError
+        return self._frozen
 
     async def freeze(self):
-        raise NotImplementedError
+        self._frozen = True
 
 
-class Signal(UserList):
-    """Coroutine-based signal implementation.
+class Signal(UserList, asyncio.Event):
+    """
+    Coroutine-based signal implementation tha behaves as an `asyncio.Event`.
 
     To connect a callback to a signal, use any list method.
 
@@ -20,7 +26,8 @@ class Signal(UserList):
     """
 
     def __init__(self, owner: Freezable) -> None:
-        super().__init__()
+        UserList.__init__(self)
+        asyncio.Event.__init__(self)
         self._owner = owner
         self.frozen = False
 
@@ -41,3 +48,4 @@ class Signal(UserList):
 
         self.frozen = True
         await self._owner.freeze()
+        self.set()
