@@ -1,7 +1,8 @@
 from aiohttp import web
-from asyncworker.signals.handlers.base import SignalHandler
-from asyncworker.options import RouteTypes
+
 from asyncworker.conf import settings
+from asyncworker.options import RouteTypes
+from asyncworker.signals.handlers.base import SignalHandler
 
 
 class HTTPServer(SignalHandler):
@@ -13,7 +14,8 @@ class HTTPServer(SignalHandler):
 
         app[RouteTypes.HTTP]["app"] = http_app = web.Application()
         for route in routes:
-            http_app.router.add_route(**route)
+            for route_def in route.aiohttp_routes():
+                route_def.register(http_app.router)
 
         app[RouteTypes.HTTP]["runner"] = web.AppRunner(http_app)
         await app[RouteTypes.HTTP]["runner"].setup()
